---
title: Reading
id: reading
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 3
kind: article
---

## Reading

With a little more deliberation in the choice of their pursuits, all
men would perhaps become essentially students and observers, for
certainly their nature and destiny are interesting to all alike. In
accumulating property for ourselves or our posterity, in founding a
family or a state, or acquiring fame even, we are mortal; but in
dealing with truth we are immortal, and need fear no change nor
accident. The oldest Egyptian or Hindoo philosopher raised a corner of
the veil from the statue of the divinity; and still the trembling robe
remains raised, and I gaze upon as fresh a glory as he did, since it
was I in him that was then so bold, and it is he in me that now reviews
the vision. No dust has settled on that robe; no time has elapsed since
that divinity was revealed. That time which we really improve, or which
is improvable, is neither past, present, nor future.

My residence was more favorable, not only to thought, but to serious
reading, than a university; and though I was beyond the range of the
ordinary circulating library, I had more than ever come within the
influence of those books which circulate round the world, whose
sentences were first written on bark, and are now merely copied from
time to time on to linen paper. Says the poet Mîr Camar Uddîn Mast,
“Being seated to run through the region of the spiritual world; I have
had this advantage in books. To be intoxicated by a single glass of
wine; I have experienced this pleasure when I have drunk the liquor of
the esoteric doctrines.” I kept Homer’s Iliad on my table through the
summer, though I looked at his page only now and then. Incessant labor
with my hands, at first, for I had my house to finish and my beans to
hoe at the same time, made more study impossible. Yet I sustained
myself by the prospect of such reading in future. I read one or two
shallow books of travel in the intervals of my work, till that
employment made me ashamed of myself, and I asked where it was then
that _I_ lived.

The student may read Homer or Æschylus in the Greek without danger of
dissipation or luxuriousness, for it implies that he in some measure
emulate their heroes, and consecrate morning hours to their pages. The
heroic books, even if printed in the character of our mother tongue,
will always be in a language dead to degenerate times; and we must
laboriously seek the meaning of each word and line, conjecturing a
larger sense than common use permits out of what wisdom and valor and
generosity we have. The modern cheap and fertile press, with all its
translations, has done little to bring us nearer to the heroic writers
of antiquity. They seem as solitary, and the letter in which they are
printed as rare and curious, as ever. It is worth the expense of
youthful days and costly hours, if you learn only some words of an
ancient language, which are raised out of the trivialness of the
street, to be perpetual suggestions and provocations. It is not in vain
that the farmer remembers and repeats the few Latin words which he has
heard. Men sometimes speak as if the study of the classics would at
length make way for more modern and practical studies; but the
adventurous student will always study classics, in whatever language
they may be written and however ancient they may be. For what are the
classics but the noblest recorded thoughts of man? They are the only
oracles which are not decayed, and there are such answers to the most
modern inquiry in them as Delphi and Dodona never gave. We might as
well omit to study Nature because she is old. To read well, that is, to
read true books in a true spirit, is a noble exercise, and one that
will task the reader more than any exercise which the customs of the
day esteem. It requires a training such as the athletes underwent, the
steady intention almost of the whole life to this object. Books must be
read as deliberately and reservedly as they were written. It is not
enough even to be able to speak the language of that nation by which
they are written, for there is a memorable interval between the spoken
and the written language, the language heard and the language read. The
one is commonly transitory, a sound, a tongue, a dialect merely, almost
brutish, and we learn it unconsciously, like the brutes, of our
mothers. The other is the maturity and experience of that; if that is
our mother tongue, this is our father tongue, a reserved and select
expression, too significant to be heard by the ear, which we must be
born again in order to speak. The crowds of men who merely _spoke_ the
Greek and Latin tongues in the middle ages were not entitled by the
accident of birth to _read_ the works of genius written in those
languages; for these were not written in that Greek or Latin which they
knew, but in the select language of literature. They had not learned
the nobler dialects of Greece and Rome, but the very materials on which
they were written were waste paper to them, and they prized instead a
cheap contemporary literature. But when the several nations of Europe
had acquired distinct though rude written languages of their own,
sufficient for the purposes of their rising literatures, then first
learning revived, and scholars were enabled to discern from that
remoteness the treasures of antiquity. What the Roman and Grecian
multitude could not _hear_, after the lapse of ages a few scholars
_read_, and a few scholars only are still reading it.

However much we may admire the orator’s occasional bursts of eloquence,
the noblest written words are commonly as far behind or above the
fleeting spoken language as the firmament with its stars is behind the
clouds. _There_ are the stars, and they who can may read them. The
astronomers forever comment on and observe them. They are not
exhalations like our daily colloquies and vaporous breath. What is
called eloquence in the forum is commonly found to be rhetoric in the
study. The orator yields to the inspiration of a transient occasion,
and speaks to the mob before him, to those who can _hear_ him; but the
writer, whose more equable life is his occasion, and who would be
distracted by the event and the crowd which inspire the orator, speaks
to the intellect and health of mankind, to all in any age who can
_understand_ him.

No wonder that Alexander carried the Iliad with him on his expeditions
in a precious casket. A written word is the choicest of relics. It is
something at once more intimate with us and more universal than any
other work of art. It is the work of art nearest to life itself. It may
be translated into every language, and not only be read but actually
breathed from all human lips;—not be represented on canvas or in marble
only, but be carved out of the breath of life itself. The symbol of an
ancient man’s thought becomes a modern man’s speech. Two thousand
summers have imparted to the monuments of Grecian literature, as to her
marbles, only a maturer golden and autumnal tint, for they have carried
their own serene and celestial atmosphere into all lands to protect
them against the corrosion of time. Books are the treasured wealth of
the world and the fit inheritance of generations and nations. Books,
the oldest and the best, stand naturally and rightfully on the shelves
of every cottage. They have no cause of their own to plead, but while
they enlighten and sustain the reader his common sense will not refuse
them. Their authors are a natural and irresistible aristocracy in every
society, and, more than kings or emperors, exert an influence on
mankind. When the illiterate and perhaps scornful trader has earned by
enterprise and industry his coveted leisure and independence, and is
admitted to the circles of wealth and fashion, he turns inevitably at
last to those still higher but yet inaccessible circles of intellect
and genius, and is sensible only of the imperfection of his culture and
the vanity and insufficiency of all his riches, and further proves his
good sense by the pains which he takes to secure for his children that
intellectual culture whose want he so keenly feels; and thus it is that
he becomes the founder of a family.

Those who have not learned to read the ancient classics in the language
in which they were written must have a very imperfect knowledge of the
history of the human race; for it is remarkable that no transcript of
them has ever been made into any modern tongue, unless our civilization
itself may be regarded as such a transcript. Homer has never yet been
printed in English, nor Æschylus, nor Virgil even—works as refined, as
solidly done, and as beautiful almost as the morning itself; for later
writers, say what we will of their genius, have rarely, if ever,
equalled the elaborate beauty and finish and the lifelong and heroic
literary labors of the ancients. They only talk of forgetting them who
never knew them. It will be soon enough to forget them when we have the
learning and the genius which will enable us to attend to and
appreciate them. That age will be rich indeed when those relics which
we call Classics, and the still older and more than classic but even
less known Scriptures of the nations, shall have still further
accumulated, when the Vaticans shall be filled with Vedas and
Zendavestas and Bibles, with Homers and Dantes and Shakespeares, and
all the centuries to come shall have successively deposited their
trophies in the forum of the world. By such a pile we may hope to scale
heaven at last.

The works of the great poets have never yet been read by mankind, for
only great poets can read them. They have only been read as the
multitude read the stars, at most astrologically, not astronomically.
Most men have learned to read to serve a paltry convenience, as they
have learned to cipher in order to keep accounts and not be cheated in
trade; but of reading as a noble intellectual exercise they know little
or nothing; yet this only is reading, in a high sense, not that which
lulls us as a luxury and suffers the nobler faculties to sleep the
while, but what we have to stand on tip-toe to read and devote our most
alert and wakeful hours to.

I think that having learned our letters we should read the best that is
in literature, and not be forever repeating our a b abs, and words of
one syllable, in the fourth or fifth classes, sitting on the lowest and
foremost form all our lives. Most men are satisfied if they read or
hear read, and perchance have been convicted by the wisdom of one good
book, the Bible, and for the rest of their lives vegetate and dissipate
their faculties in what is called easy reading. There is a work in
several volumes in our Circulating Library entitled Little Reading,
which I thought referred to a town of that name which I had not been
to. There are those who, like cormorants and ostriches, can digest all
sorts of this, even after the fullest dinner of meats and vegetables,
for they suffer nothing to be wasted. If others are the machines to
provide this provender, they are the machines to read it. They read the
nine thousandth tale about Zebulon and Sephronia, and how they loved as
none had ever loved before, and neither did the course of their true
love run smooth,—at any rate, how it did run and stumble, and get up
again and go on! how some poor unfortunate got up on to a steeple, who
had better never have gone up as far as the belfry; and then, having
needlessly got him up there, the happy novelist rings the bell for all
the world to come together and hear, O dear! how he did get down again!
For my part, I think that they had better metamorphose all such
aspiring heroes of universal noveldom into man weathercocks, as they
used to put heroes among the constellations, and let them swing round
there till they are rusty, and not come down at all to bother honest
men with their pranks. The next time the novelist rings the bell I will
not stir though the meeting-house burn down. “The Skip of the
Tip-Toe-Hop, a Romance of the Middle Ages, by the celebrated author of
‘Tittle-Tol-Tan,’ to appear in monthly parts; a great rush; don’t all
come together.” All this they read with saucer eyes, and erect and
primitive curiosity, and with unwearied gizzard, whose corrugations
even yet need no sharpening, just as some little four-year-old bencher
his two-cent gilt-covered edition of Cinderella,—without any
improvement, that I can see, in the pronunciation, or accent, or
emphasis, or any more skill in extracting or inserting the moral. The
result is dulness of sight, a stagnation of the vital circulations, and
a general deliquium and sloughing off of all the intellectual
faculties. This sort of gingerbread is baked daily and more sedulously
than pure wheat or rye-and-Indian in almost every oven, and finds a
surer market.

The best books are not read even by those who are called good readers.
What does our Concord culture amount to? There is in this town, with a
very few exceptions, no taste for the best or for very good books even
in English literature, whose words all can read and spell. Even the
college-bred and so called liberally educated men here and elsewhere
have really little or no acquaintance with the English classics; and as
for the recorded wisdom of mankind, the ancient classics and Bibles,
which are accessible to all who will know of them, there are the
feeblest efforts any where made to become acquainted with them. I know
a woodchopper, of middle age, who takes a French paper, not for news as
he says, for he is above that, but to “keep himself in practice,” he
being a Canadian by birth; and when I ask him what he considers the
best thing he can do in this world, he says, beside this, to keep up
and add to his English. This is about as much as the college bred
generally do or aspire to do, and they take an English paper for the
purpose. One who has just come from reading perhaps one of the best
English books will find how many with whom he can converse about it? Or
suppose he comes from reading a Greek or Latin classic in the original,
whose praises are familiar even to the so called illiterate; he will
find nobody at all to speak to, but must keep silence about it. Indeed,
there is hardly the professor in our colleges, who, if he has mastered
the difficulties of the language, has proportionally mastered the
difficulties of the wit and poetry of a Greek poet, and has any
sympathy to impart to the alert and heroic reader; and as for the
sacred Scriptures, or Bibles of mankind, who in this town can tell me
even their titles? Most men do not know that any nation but the Hebrews
have had a scripture. A man, any man, will go considerably out of his
way to pick up a silver dollar; but here are golden words, which the
wisest men of antiquity have uttered, and whose worth the wise of every
succeeding age have assured us of;—and yet we learn to read only as far
as Easy Reading, the primers and class-books, and when we leave school,
the “Little Reading,” and story books, which are for boys and
beginners; and our reading, our conversation and thinking, are all on a
very low level, worthy only of pygmies and manikins.

I aspire to be acquainted with wiser men than this our Concord soil has
produced, whose names are hardly known here. Or shall I hear the name
of Plato and never read his book? As if Plato were my townsman and I
never saw him,—my next neighbor and I never heard him speak or attended
to the wisdom of his words. But how actually is it? His Dialogues,
which contain what was immortal in him, lie on the next shelf, and yet
I never read them. We are underbred and low-lived and illiterate; and
in this respect I confess I do not make any very broad distinction
between the illiterateness of my townsman who cannot read at all, and
the illiterateness of him who has learned to read only what is for
children and feeble intellects. We should be as good as the worthies of
antiquity, but partly by first knowing how good they were. We are a
race of tit-men, and soar but little higher in our intellectual flights
than the columns of the daily paper.

It is not all books that are as dull as their readers. There are
probably words addressed to our condition exactly, which, if we could
really hear and understand, would be more salutary than the morning or
the spring to our lives, and possibly put a new aspect on the face of
things for us. How many a man has dated a new era in his life from the
reading of a book. The book exists for us perchance which will explain
our miracles and reveal new ones. The at present unutterable things we
may find somewhere uttered. These same questions that disturb and
puzzle and confound us have in their turn occurred to all the wise men;
not one has been omitted; and each has answered them, according to his
ability, by his words and his life. Moreover, with wisdom we shall
learn liberality. The solitary hired man on a farm in the outskirts of
Concord, who has had his second birth and peculiar religious
experience, and is driven as he believes into the silent gravity and
exclusiveness by his faith, may think it is not true; but Zoroaster,
thousands of years ago, travelled the same road and had the same
experience; but he, being wise, knew it to be universal, and treated
his neighbors accordingly, and is even said to have invented and
established worship among men. Let him humbly commune with Zoroaster
then, and through the liberalizing influence of all the worthies, with
Jesus Christ himself, and let “our church” go by the board.

We boast that we belong to the nineteenth century and are making the
most rapid strides of any nation. But consider how little this village
does for its own culture. I do not wish to flatter my townsmen, nor to
be flattered by them, for that will not advance either of us. We need
to be provoked,—goaded like oxen, as we are, into a trot. We have a
comparatively decent system of common schools, schools for infants
only; but excepting the half-starved Lyceum in the winter, and latterly
the puny beginning of a library suggested by the state, no school for
ourselves. We spend more on almost any article of bodily aliment or
ailment than on our mental aliment. It is time that we had uncommon
schools, that we did not leave off our education when we begin to be
men and women. It is time that villages were universities, and their
elder inhabitants the fellows of universities, with leisure—if they are
indeed so well off—to pursue liberal studies the rest of their lives.
Shall the world be confined to one Paris or one Oxford forever? Cannot
students be boarded here and get a liberal education under the skies of
Concord? Can we not hire some Abelard to lecture to us? Alas! what with
foddering the cattle and tending the store, we are kept from school too
long, and our education is sadly neglected. In this country, the
village should in some respects take the place of the nobleman of
Europe. It should be the patron of the fine arts. It is rich enough. It
wants only the magnanimity and refinement. It can spend money enough on
such things as farmers and traders value, but it is thought Utopian to
propose spending money for things which more intelligent men know to be
of far more worth. This town has spent seventeen thousand dollars on a
town-house, thank fortune or politics, but probably it will not spend
so much on living wit, the true meat to put into that shell, in a
hundred years. The one hundred and twenty-five dollars annually
subscribed for a Lyceum in the winter is better spent than any other
equal sum raised in the town. If we live in the nineteenth century, why
should we not enjoy the advantages which the nineteenth century offers?
Why should our life be in any respect provincial? If we will read
newspapers, why not skip the gossip of Boston and take the best
newspaper in the world at once?—not be sucking the pap of “neutral
family” papers, or browsing “Olive-Branches” here in New England. Let
the reports of all the learned societies come to us, and we will see if
they know any thing. Why should we leave it to Harper & Brothers and
Redding & Co. to select our reading? As the nobleman of cultivated
taste surrounds himself with whatever conduces to his
culture,—genius—learning—wit—books—paintings—statuary—music—
philosophical instruments, and the like; so let the village do,—not
stop short at a pedagogue, a parson, a sexton, a parish library, and
three selectmen, because our pilgrim forefathers got through a cold
winter once on a bleak rock with these. To act collectively is
according to the spirit of our institutions; and I am confident that,
as our circumstances are more flourishing, our means are greater than
the nobleman’s. New England can hire all the wise men in the world to
come and teach her, and board them round the while, and not be
provincial at all. That is the _uncommon_ school we want. Instead of
noblemen, let us have noble villages of men. If it is necessary, omit
one bridge over the river, go round a little there, and throw one arch
at least over the darker gulf of ignorance which surrounds us.


